@@ -73,6 +73,7 @@ import org.apache.sshd.common.util.ExceptionUtils;
 import org.apache.sshd.common.util.GenericUtils;
 import org.apache.sshd.common.util.ValidateUtils;
 import org.apache.sshd.common.util.buffer.Buffer;
+import org.apache.sshd.common.util.security.bouncycastle.BouncyCastleEncryptedPrivateKeyInfoDecryptor;
 import org.apache.sshd.common.util.security.bouncycastle.BouncyCastleGeneratorHostKeyProvider;
 import org.apache.sshd.common.util.security.bouncycastle.BouncyCastleKeyPairResourceParser;
 import org.apache.sshd.common.util.security.bouncycastle.BouncyCastleRandomFactory;
@@ -89,7 +90,7 @@ import org.slf4j.LoggerFactory;
  */
 public final class SecurityUtils {
     /**
-     * Bouncycastle JCE provider name
+     * Bouncy Castle {@link SecurityProviderRegistrar} name.
      */
     public static final String BOUNCY_CASTLE = "BC";
 
@@ -133,6 +134,7 @@ public final class SecurityUtils {
     public static final String SECURITY_PROVIDER_REGISTRARS = "org.apache.sshd.security.registrars";
     public static final List<String> DEFAULT_SECURITY_PROVIDER_REGISTRARS = Collections.unmodifiableList(
             Arrays.asList(
+                    "org.apache.sshd.common.util.security.SunJCESecurityProviderRegistrar",
                     "org.apache.sshd.common.util.security.bouncycastle.BouncyCastleSecurityProviderRegistrar",
                     "org.apache.sshd.common.util.security.eddsa.EdDSASecurityProviderRegistrar"));
 
@@ -163,6 +165,15 @@ public final class SecurityUtils {
 
     public static final String PROP_DEFAULT_SECURITY_PROVIDER = "org.apache.sshd.security.defaultProvider";
 
+    /**
+     * A boolean system property that can be set to {@code "true"} to enable FIPS mode. In FIPS mode, crypto-algorithms
+     * not approved in FIPS-140 will not be available.
+     * <p>
+     * <b>Note:</b> if this system property is not {@code "true"}, it can be overridden via {@link #setFipsMode()}.
+     * </p>
+     */
+    public static final String FIPS_ENABLED = "org.apache.sshd.security.fipsEnabled";
+
     private static final AtomicInteger MIN_DHG_KEY_SIZE_HOLDER = new AtomicInteger(0);
     private static final AtomicInteger MAX_DHG_KEY_SIZE_HOLDER = new AtomicInteger(0);
 
@@ -179,12 +190,44 @@ public final class SecurityUtils {
 
     private static final AtomicReference<SecurityProviderChoice> DEFAULT_PROVIDER_HOLDER = new AtomicReference<>();
 
+    private static final AtomicReference<Boolean> FIPS_MODE = new AtomicReference<>();
+
     private static Boolean hasEcc;
 
     private SecurityUtils() {
         throw new UnsupportedOperationException("No instance");
     }
 
+    /**
+     * Unconditionally set FIPS mode, overriding the {@link #FIPS_ENABLED} system property.
+     *
+     * @throws IllegalStateException if a call to {@link #isFipsMode()} had already occurred and returned {@code false}.
+     */
+    public static void setFipsMode() {
+        if (!FIPS_MODE.compareAndSet(null, Boolean.TRUE)) {
+            if (!Boolean.TRUE.equals(FIPS_MODE.get())) {
+                throw new IllegalStateException("FIPS mode was already set to FALSE");
+            }
+        }
+    }
+
+    /**
+     * Tells whether FIPS mode is enabled, either through the system property {@link #FIPS_ENABLED} or via
+     * {@link #setFipsMode()}.
+     *
+     * @return {@code true} if FIPS mode is enabled, {@code false} otherwise.
+     */
+    public static boolean isFipsMode() {
+        Boolean value = FIPS_MODE.get();
+        if (FIPS_MODE.get() == null) {
+            value = Boolean.getBoolean(FIPS_ENABLED);
+            if (!FIPS_MODE.compareAndSet(null, value)) {
+                value = FIPS_MODE.get();
+            }
+        }
+        return value;
+    }
+
     /**
      * @param  name The provider's name - never {@code null}/empty
      * @return      {@code true} if the provider is marked as disabled a-priori
@@ -438,7 +481,7 @@ public final class SecurityUtils {
                         } else if (e instanceof Error) {
                             throw (Error) e;
                         } else {
-                            throw new RuntimeException(e);
+                            throw new IllegalStateException(e);
                         }
                     }
 
@@ -488,7 +531,7 @@ public final class SecurityUtils {
                 Logger logger = LoggerFactory.getLogger(SecurityUtils.class);
                 logger.error("Failed {} to register {} as a JCE provider: {}",
                         t.getClass().getSimpleName(), name, t.getMessage());
-                throw new RuntimeException("Failed to register " + name + " as a JCE provider", t);
+                throw new IllegalArgumentException("Failed to register " + name + " as a JCE provider", t);
             }
         }
 
@@ -540,12 +583,17 @@ public final class SecurityUtils {
         return BouncyCastleKeyPairResourceParser.INSTANCE;
     }
 
+    public static Decryptor getBouncycastleEncryptedPrivateKeyInfoDecryptor() {
+        ValidateUtils.checkTrue(isBouncyCastleRegistered(), "BouncyCastle not registered");
+        return BouncyCastleEncryptedPrivateKeyInfoDecryptor.INSTANCE;
+    }
+
     /**
      * @return If {@link #isBouncyCastleRegistered()} then a {@link BouncyCastleRandomFactory} instance, otherwise a
      *         {@link JceRandomFactory} one
      */
     public static RandomFactory getRandomFactory() {
-        if (isBouncyCastleRegistered()) {
+        if (isBouncyCastleRegistered() && BouncyCastleRandomFactory.INSTANCE.isSupported()) {
             return BouncyCastleRandomFactory.INSTANCE;
         } else {
             return JceRandomFactory.INSTANCE;
@@ -558,6 +606,9 @@ public final class SecurityUtils {
      * @return {@code true} if EDDSA curves (e.g., {@code ed25519}) are supported
      */
     public static boolean isEDDSACurveSupported() {
+        if (isFipsMode()) {
+            return false;
+        }
         register();
 
         SecurityProviderRegistrar r = getRegisteredProvider(EDDSA);
@@ -731,7 +782,7 @@ public final class SecurityUtils {
             } else if (e instanceof Error) {
                 throw (Error) e;
             } else {
-                throw new RuntimeException(e);
+                throw new IllegalArgumentException(e);
             }
         }
     }
