@@ -48,6 +48,7 @@ import java.util.Set;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.LinkedBlockingDeque;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.stream.Collectors;
@@ -78,20 +79,30 @@ import org.apache.sshd.server.global.TcpipForwardHandler;
 import org.apache.sshd.util.test.BaseTestSupport;
 import org.apache.sshd.util.test.CoreTestSupportUtils;
 import org.apache.sshd.util.test.JSchLogger;
+import org.apache.sshd.util.test.JSchUtils;
 import org.apache.sshd.util.test.SimpleUserInfo;
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.FixMethodOrder;
-import org.junit.Test;
-import org.junit.runners.MethodSorters;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.Assumptions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.MethodOrderer.MethodName;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestMethodOrder;
+import org.junit.jupiter.api.Timeout;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 /**
  * Port forwarding tests
  */
-@FixMethodOrder(MethodSorters.NAME_ASCENDING)
+@TestMethodOrder(MethodName.class)
 @SuppressWarnings("checkstyle:MethodCount")
 public class PortForwardingTest extends BaseTestSupport {
 
@@ -179,8 +190,8 @@ public class PortForwardingTest extends BaseTestSupport {
         super();
     }
 
-    @BeforeClass
-    public static void setUpTestEnvironment() throws Exception {
+    @BeforeAll
+    static void setUpTestEnvironment() throws Exception {
         JSchLogger.init();
         sshd = CoreTestSupportUtils.setupTestFullSupportServer(PortForwardingTest.class);
         CoreModuleProperties.WINDOW_SIZE.set(sshd, 2048L);
@@ -255,8 +266,8 @@ public class PortForwardingTest extends BaseTestSupport {
         client.start();
     }
 
-    @AfterClass
-    public static void tearDownTestEnvironment() throws Exception {
+    @AfterAll
+    static void tearDownTestEnvironment() throws Exception {
         if (sshd != null) {
             sshd.stop(true);
         }
@@ -268,8 +279,8 @@ public class PortForwardingTest extends BaseTestSupport {
         }
     }
 
-    @Before
-    public void setUp() {
+    @BeforeEach
+    void setUp() {
         if (!REQUESTS_QUEUE.isEmpty()) {
             REQUESTS_QUEUE.clear();
         }
@@ -296,11 +307,11 @@ public class PortForwardingTest extends BaseTestSupport {
     }
 
     @Test
-    public void testRemoteForwarding() throws Exception {
+    void remoteForwarding() throws Exception {
         Session session = createSession();
         try {
             int forwardedPort = CoreTestSupportUtils.getFreePort();
-            session.setPortForwardingR(forwardedPort, TEST_LOCALHOST, echoPort);
+            JSchUtils.setRemotePortForwarding(session, forwardedPort, TEST_LOCALHOST, echoPort);
             waitForForwardingRequest(TcpipForwardHandler.REQUEST, DEFAULT_TIMEOUT);
 
             try (Socket s = new Socket(TEST_LOCALHOST, forwardedPort);
@@ -317,7 +328,7 @@ public class PortForwardingTest extends BaseTestSupport {
                 byte[] buf = new byte[bytes.length + Long.SIZE];
                 int n = input.read(buf);
                 String res = new String(buf, 0, n, StandardCharsets.UTF_8);
-                assertEquals("Mismatched data", expected, res);
+                assertEquals(expected, res, "Mismatched data");
             } finally {
                 session.delPortForwardingR(forwardedPort);
             }
@@ -326,18 +337,24 @@ public class PortForwardingTest extends BaseTestSupport {
         }
     }
 
+    private boolean isMina() {
+        return "MinaServiceFactoryFactory".equals(getIoServiceProvider().getClass().getSimpleName());
+    }
+
     @Test
-    public void testRemoteForwardingSecondTimeInSameSession() throws Exception {
+    void remoteForwardingSecondTimeInSameSession() throws Exception {
+        // TODO: remove assumption once DIRMINA-1169 is fixed in the MINA version we are using
+        Assumptions.assumeFalse(isMina(), "Skipped for MINA transport; can work reliably only once DIRMINS-1169 is fixed");
         Session session = createSession();
         try {
             int forwardedPort = CoreTestSupportUtils.getFreePort();
-            session.setPortForwardingR(forwardedPort, TEST_LOCALHOST, echoPort);
+            JSchUtils.setRemotePortForwarding(session, forwardedPort, TEST_LOCALHOST, echoPort);
             waitForForwardingRequest(TcpipForwardHandler.REQUEST, DEFAULT_TIMEOUT);
 
             session.delPortForwardingR(TEST_LOCALHOST, forwardedPort);
             waitForForwardingRequest(CancelTcpipForwardHandler.REQUEST, DEFAULT_TIMEOUT);
 
-            session.setPortForwardingR(forwardedPort, TEST_LOCALHOST, echoPort);
+            JSchUtils.setRemotePortForwarding(session, forwardedPort, TEST_LOCALHOST, echoPort);
             waitForForwardingRequest(TcpipForwardHandler.REQUEST, DEFAULT_TIMEOUT);
 
             try (Socket s = new Socket(TEST_LOCALHOST, forwardedPort);
@@ -354,7 +371,7 @@ public class PortForwardingTest extends BaseTestSupport {
                 byte[] buf = new byte[bytes.length + Long.SIZE];
                 int n = input.read(buf);
                 String res = new String(buf, 0, n, StandardCharsets.UTF_8);
-                assertEquals("Mismatched data", expected, res);
+                assertEquals(expected, res, "Mismatched data");
             } finally {
                 session.delPortForwardingR(TEST_LOCALHOST, forwardedPort);
             }
@@ -364,7 +381,7 @@ public class PortForwardingTest extends BaseTestSupport {
     }
 
     @Test
-    public void testRemoteForwardingNative() throws Exception {
+    void remoteForwardingNative() throws Exception {
         try (ClientSession session = createNativeSession(null)) {
             SshdSocketAddress remote = new SshdSocketAddress("", 0);
             SshdSocketAddress local = new SshdSocketAddress(TEST_LOCALHOST, echoPort);
@@ -384,7 +401,7 @@ public class PortForwardingTest extends BaseTestSupport {
                 byte[] buf = new byte[bytes.length + Long.SIZE];
                 int n = input.read(buf);
                 String res = new String(buf, 0, n);
-                assertEquals("Mismatched data", expected, res);
+                assertEquals(expected, res, "Mismatched data");
             } finally {
                 session.stopRemotePortForwarding(remote);
             }
@@ -392,7 +409,7 @@ public class PortForwardingTest extends BaseTestSupport {
     }
 
     @Test
-    public void testRemoteForwardingNativeBigPayload() throws Exception {
+    void remoteForwardingNativeBigPayload() throws Exception {
         AtomicReference<SshdSocketAddress> localAddressHolder = new AtomicReference<>();
         AtomicReference<SshdSocketAddress> remoteAddressHolder = new AtomicReference<>();
         AtomicReference<SshdSocketAddress> boundAddressHolder = new AtomicReference<>();
@@ -404,8 +421,8 @@ public class PortForwardingTest extends BaseTestSupport {
                     org.apache.sshd.common.session.Session session, SshdSocketAddress address, boolean localForwarding,
                     SshdSocketAddress remoteAddress, Throwable reason)
                     throws IOException {
-                assertFalse("Unexpected local tunnel has been torn down: address=" + address, localForwarding);
-                assertEquals("Tear down indication not invoked", 1, tearDownSignal.get());
+                assertFalse(localForwarding, "Unexpected local tunnel has been torn down: address=" + address);
+                assertEquals(1, tearDownSignal.get(), "Tear down indication not invoked");
             }
 
             @Override
@@ -421,8 +438,8 @@ public class PortForwardingTest extends BaseTestSupport {
                     org.apache.sshd.common.session.Session session, SshdSocketAddress address, boolean localForwarding,
                     SshdSocketAddress remoteAddress)
                     throws IOException {
-                assertFalse("Unexpected local tunnel being torn down: address=" + address, localForwarding);
-                assertEquals("Duplicate tear down signalling", 1, tearDownSignal.incrementAndGet());
+                assertFalse(localForwarding, "Unexpected local tunnel being torn down: address=" + address);
+                assertEquals(1, tearDownSignal.incrementAndGet(), "Duplicate tear down signalling");
             }
 
             @Override
@@ -437,12 +454,12 @@ public class PortForwardingTest extends BaseTestSupport {
                     org.apache.sshd.common.session.Session session, SshdSocketAddress local, SshdSocketAddress remote,
                     boolean localForwarding)
                     throws IOException {
-                assertFalse("Unexpected local tunnel being established: local=" + local + ", remote=" + remote,
-                        localForwarding);
-                assertNull("Duplicate establishment indication call for local address=" + local,
-                        localAddressHolder.getAndSet(local));
-                assertNull("Duplicate establishment indication call for remote address=" + remote,
-                        remoteAddressHolder.getAndSet(remote));
+                assertFalse(localForwarding,
+                        "Unexpected local tunnel being established: local=" + local + ", remote=" + remote);
+                assertNull(localAddressHolder.getAndSet(local),
+                        "Duplicate establishment indication call for local address=" + local);
+                assertNull(remoteAddressHolder.getAndSet(remote),
+                        "Duplicate establishment indication call for remote address=" + remote);
             }
 
             @Override
@@ -457,13 +474,13 @@ public class PortForwardingTest extends BaseTestSupport {
                     org.apache.sshd.common.session.Session session, SshdSocketAddress local,
                     SshdSocketAddress remote, boolean localForwarding, SshdSocketAddress boundAddress, Throwable reason)
                     throws IOException {
-                assertFalse("Unexpected local tunnel has been established: local=" + local + ", remote=" + remote + ", bound="
-                            + boundAddress,
-                        localForwarding);
-                assertSame("Mismatched established tunnel local address", local, localAddressHolder.get());
-                assertSame("Mismatched established tunnel remote address", remote, remoteAddressHolder.get());
-                assertNull("Duplicate establishment indication call for bound address=" + boundAddress,
-                        boundAddressHolder.getAndSet(boundAddress));
+                assertFalse(localForwarding,
+                        "Unexpected local tunnel has been established: local=" + local + ", remote=" + remote + ", bound="
+                                             + boundAddress);
+                assertSame(local, localAddressHolder.get(), "Mismatched established tunnel local address");
+                assertSame(remote, remoteAddressHolder.get(), "Mismatched established tunnel remote address");
+                assertNull(boundAddressHolder.getAndSet(boundAddress),
+                        "Duplicate establishment indication call for bound address=" + boundAddress);
             }
 
             @Override
@@ -479,8 +496,8 @@ public class PortForwardingTest extends BaseTestSupport {
         try (ClientSession session = createNativeSession(listener);
              ExplicitPortForwardingTracker tracker = session.createRemotePortForwardingTracker(new SshdSocketAddress("", 0),
                      new SshdSocketAddress(TEST_LOCALHOST, echoPort))) {
-            assertTrue("Tracker not marked as open", tracker.isOpen());
-            assertFalse("Tracker not marked as remote", tracker.isLocalForwarding());
+            assertTrue(tracker.isOpen(), "Tracker not marked as open");
+            assertFalse(tracker.isLocalForwarding(), "Tracker not marked as remote");
 
             SshdSocketAddress bound = tracker.getBoundAddress();
             try (Socket s = new Socket(bound.getHostName(), bound.getPort());
@@ -499,23 +516,23 @@ public class PortForwardingTest extends BaseTestSupport {
 
                     int n = input.read(buf);
                     String res = new String(buf, 0, n, StandardCharsets.UTF_8);
-                    assertEquals("Mismatched data at iteration #" + i, expected, res);
+                    assertEquals(expected, res, "Mismatched data at iteration #" + i);
                 }
             } finally {
                 tracker.close();
             }
-            assertFalse("Tracker not marked as closed", tracker.isOpen());
+            assertFalse(tracker.isOpen(), "Tracker not marked as closed");
         } finally {
             client.removePortForwardingEventListener(listener);
         }
 
-        assertNotNull("Local tunnel address not indicated", localAddressHolder.getAndSet(null));
-        assertNotNull("Remote tunnel address not indicated", remoteAddressHolder.getAndSet(null));
-        assertNotNull("Bound tunnel address not indicated", boundAddressHolder.getAndSet(null));
+        assertNotNull(localAddressHolder.getAndSet(null), "Local tunnel address not indicated");
+        assertNotNull(remoteAddressHolder.getAndSet(null), "Remote tunnel address not indicated");
+        assertNotNull(boundAddressHolder.getAndSet(null), "Bound tunnel address not indicated");
     }
 
     @Test
-    public void testLocalForwarding() throws Exception {
+    void localForwarding() throws Exception {
         Session session = createSession();
         try {
             int forwardedPort = CoreTestSupportUtils.getFreePort();
@@ -536,7 +553,7 @@ public class PortForwardingTest extends BaseTestSupport {
                 byte[] buf = new byte[bytes.length + Long.SIZE];
                 int n = input.read(buf);
                 String res = new String(buf, 0, n, StandardCharsets.UTF_8);
-                assertEquals("Mismatched data", expected, res);
+                assertEquals(expected, res, "Mismatched data");
             } finally {
                 session.delPortForwardingL(forwardedPort);
             }
@@ -546,11 +563,12 @@ public class PortForwardingTest extends BaseTestSupport {
     }
 
     @Test
-    public void testLocalForwardingNative() throws Exception {
+    void localForwardingNative() throws Exception {
         AtomicReference<SshdSocketAddress> localAddressHolder = new AtomicReference<>();
         AtomicReference<SshdSocketAddress> remoteAddressHolder = new AtomicReference<>();
         AtomicReference<SshdSocketAddress> boundAddressHolder = new AtomicReference<>();
         AtomicInteger tearDownSignal = new AtomicInteger(0);
+        AtomicBoolean tearDownSignalInvoked = new AtomicBoolean();
         @SuppressWarnings("checkstyle:anoninnerlength")
         PortForwardingEventListener listener = new PortForwardingEventListener() {
             @Override
@@ -558,8 +576,9 @@ public class PortForwardingTest extends BaseTestSupport {
                     org.apache.sshd.common.session.Session session, SshdSocketAddress address, boolean localForwarding,
                     SshdSocketAddress remoteAddress, Throwable reason)
                     throws IOException {
-                assertTrue("Unexpected remote tunnel has been torn down: address=" + address, localForwarding);
-                assertEquals("Tear down indication not invoked", 1, tearDownSignal.get());
+                assertTrue(localForwarding, "Unexpected remote tunnel has been torn down: address=" + address);
+                assertEquals(1, tearDownSignal.get(), "Tear down indication not invoked");
+                tearDownSignalInvoked.set(true);
             }
 
             @Override
@@ -575,8 +594,8 @@ public class PortForwardingTest extends BaseTestSupport {
                     org.apache.sshd.common.session.Session session, SshdSocketAddress address, boolean localForwarding,
                     SshdSocketAddress remoteAddress)
                     throws IOException {
-                assertTrue("Unexpected remote tunnel being torn down: address=" + address, localForwarding);
-                assertEquals("Duplicate tear down signalling", 1, tearDownSignal.incrementAndGet());
+                assertTrue(localForwarding, "Unexpected remote tunnel being torn down: address=" + address);
+                assertEquals(1, tearDownSignal.incrementAndGet(), "Duplicate tear down signalling");
             }
 
             @Override
@@ -591,12 +610,12 @@ public class PortForwardingTest extends BaseTestSupport {
                     org.apache.sshd.common.session.Session session, SshdSocketAddress local, SshdSocketAddress remote,
                     boolean localForwarding)
                     throws IOException {
-                assertTrue("Unexpected remote tunnel being established: local=" + local + ", remote=" + remote,
-                        localForwarding);
-                assertNull("Duplicate establishment indication call for local address=" + local,
-                        localAddressHolder.getAndSet(local));
-                assertNull("Duplicate establishment indication call for remote address=" + remote,
-                        remoteAddressHolder.getAndSet(remote));
+                assertTrue(localForwarding,
+                        "Unexpected remote tunnel being established: local=" + local + ", remote=" + remote);
+                assertNull(localAddressHolder.getAndSet(local),
+                        "Duplicate establishment indication call for local address=" + local);
+                assertNull(remoteAddressHolder.getAndSet(remote),
+                        "Duplicate establishment indication call for remote address=" + remote);
             }
 
             @Override
@@ -611,13 +630,13 @@ public class PortForwardingTest extends BaseTestSupport {
                     org.apache.sshd.common.session.Session session, SshdSocketAddress local,
                     SshdSocketAddress remote, boolean localForwarding, SshdSocketAddress boundAddress, Throwable reason)
                     throws IOException {
-                assertTrue("Unexpected remote tunnel has been established: local=" + local + ", remote=" + remote + ", bound="
-                           + boundAddress,
-                        localForwarding);
-                assertSame("Mismatched established tunnel local address", local, localAddressHolder.get());
-                assertSame("Mismatched established tunnel remote address", remote, remoteAddressHolder.get());
-                assertNull("Duplicate establishment indication call for bound address=" + boundAddress,
-                        boundAddressHolder.getAndSet(boundAddress));
+                assertTrue(localForwarding,
+                        "Unexpected remote tunnel has been established: local=" + local + ", remote=" + remote + ", bound="
+                                            + boundAddress);
+                assertSame(local, localAddressHolder.get(), "Mismatched established tunnel local address");
+                assertSame(remote, remoteAddressHolder.get(), "Mismatched established tunnel remote address");
+                assertNull(boundAddressHolder.getAndSet(boundAddress),
+                        "Duplicate establishment indication call for bound address=" + boundAddress);
             }
 
             @Override
@@ -633,8 +652,8 @@ public class PortForwardingTest extends BaseTestSupport {
         try (ClientSession session = createNativeSession(listener);
              ExplicitPortForwardingTracker tracker = session.createLocalPortForwardingTracker(new SshdSocketAddress("", 0),
                      new SshdSocketAddress(TEST_LOCALHOST, echoPort))) {
-            assertTrue("Tracker not marked as open", tracker.isOpen());
-            assertTrue("Tracker not marked as local", tracker.isLocalForwarding());
+            assertTrue(tracker.isOpen(), "Tracker not marked as open");
+            assertTrue(tracker.isLocalForwarding(), "Tracker not marked as local");
 
             SshdSocketAddress bound = tracker.getBoundAddress();
             try (Socket s = new Socket(bound.getHostName(), bound.getPort());
@@ -651,25 +670,26 @@ public class PortForwardingTest extends BaseTestSupport {
 
                 byte[] buf = new byte[bytes.length + Long.SIZE];
                 int n = input.read(buf);
-                assertTrue("No data read from tunnel", n > 0);
+                assertTrue(n > 0, "No data read from tunnel");
 
                 String res = new String(buf, 0, n, StandardCharsets.UTF_8);
-                assertEquals("Mismatched data", expected, res);
+                assertEquals(expected, res, "Mismatched data");
             } finally {
                 tracker.close();
             }
-            assertFalse("Tracker not marked as closed", tracker.isOpen());
+            assertFalse(tracker.isOpen(), "Tracker not marked as closed");
+            assertTrue(tearDownSignalInvoked.get(), "Tear down signal did not occur");
         } finally {
             client.removePortForwardingEventListener(listener);
         }
 
-        assertNotNull("Local tunnel address not indicated", localAddressHolder.getAndSet(null));
-        assertNotNull("Remote tunnel address not indicated", remoteAddressHolder.getAndSet(null));
-        assertNotNull("Bound tunnel address not indicated", boundAddressHolder.getAndSet(null));
+        assertNotNull(localAddressHolder.getAndSet(null), "Local tunnel address not indicated");
+        assertNotNull(remoteAddressHolder.getAndSet(null), "Remote tunnel address not indicated");
+        assertNotNull(boundAddressHolder.getAndSet(null), "Bound tunnel address not indicated");
     }
 
     @Test
-    public void testLocalForwardingNativeReuse() throws Exception {
+    void localForwardingNativeReuse() throws Exception {
         try (ClientSession session = createNativeSession(null)) {
             SshdSocketAddress local = new SshdSocketAddress("", 0);
             SshdSocketAddress remote = new SshdSocketAddress(TEST_LOCALHOST, echoPort);
@@ -683,7 +703,7 @@ public class PortForwardingTest extends BaseTestSupport {
     }
 
     @Test
-    public void testLocalForwardingNativeBigPayload() throws Exception {
+    void localForwardingNativeBigPayload() throws Exception {
         try (ClientSession session = createNativeSession(null)) {
             String expected = getCurrentTestName();
             byte[] bytes = expected.getBytes(StandardCharsets.UTF_8);
@@ -703,10 +723,10 @@ public class PortForwardingTest extends BaseTestSupport {
                     output.flush();
 
                     int n = input.read(buf);
-                    assertTrue("No data read from tunnel", n > 0);
+                    assertTrue(n > 0, "No data read from tunnel");
 
                     String res = new String(buf, 0, n, StandardCharsets.UTF_8);
-                    assertEquals("Mismatched data at iteration #" + i, expected, res);
+                    assertEquals(expected, res, "Mismatched data at iteration #" + i);
                 }
             } finally {
                 session.stopLocalPortForwarding(bound);
@@ -715,7 +735,7 @@ public class PortForwardingTest extends BaseTestSupport {
     }
 
     @Test
-    public void testForwardingChannel() throws Exception {
+    void forwardingChannel() throws Exception {
         try (ClientSession session = createNativeSession(null)) {
             SshdSocketAddress local = new SshdSocketAddress("", 0);
             SshdSocketAddress remote = new SshdSocketAddress(TEST_LOCALHOST, echoPort);
@@ -734,20 +754,21 @@ public class PortForwardingTest extends BaseTestSupport {
                     byte[] buf = new byte[bytes.length + Long.SIZE];
                     int n = input.read(buf);
                     String res = new String(buf, 0, n, StandardCharsets.UTF_8);
-                    assertEquals("Mismatched data", expected, res);
+                    assertEquals(expected, res, "Mismatched data");
                 }
                 channel.close(false);
             }
         }
     }
 
-    @Test(timeout = 45000)
-    public void testRemoteForwardingWithDisconnect() throws Exception {
+    @Test
+    @Timeout(value = 45000, unit = TimeUnit.MILLISECONDS)
+    void remoteForwardingWithDisconnect() throws Exception {
         Session session = createSession();
         try {
             // 1. Create a Port Forward
             int forwardedPort = CoreTestSupportUtils.getFreePort();
-            session.setPortForwardingR(forwardedPort, TEST_LOCALHOST, echoPort);
+            JSchUtils.setRemotePortForwarding(session, forwardedPort, TEST_LOCALHOST, echoPort);
             waitForForwardingRequest(TcpipForwardHandler.REQUEST, DEFAULT_TIMEOUT);
 
             // 2. Establish a connection through it
@@ -787,8 +808,9 @@ public class PortForwardingTest extends BaseTestSupport {
         }
     }
 
-    @Test   // see SSHD-1066
-    public void testLocalBindingOnDifferentInterfaces() throws Exception {
+    // see SSHD-1066
+    @Test
+    void localBindingOnDifferentInterfaces() throws Exception {
         InetSocketAddress addr = (InetSocketAddress) GenericUtils.head(sshd.getBoundAddresses());
         log.info("{} - using bound address={}", getCurrentTestName(), addr);
 
@@ -839,7 +861,7 @@ public class PortForwardingTest extends BaseTestSupport {
              BufferedReader in = new BufferedReader(new InputStreamReader(inputStream))) {
             result = in.lines().collect(Collectors.joining(System.lineSeparator()));
         }
-        assertEquals("Unexpected server response", "OK", result);
+        assertEquals("OK", result, "Unexpected server response");
     }
 
     /**
@@ -853,10 +875,10 @@ public class PortForwardingTest extends BaseTestSupport {
         fSocket.setAccessible(true);
 
         try (Socket socket = (Socket) fSocket.get(session)) {
-            assertTrue("socket is not connected", socket.isConnected());
-            assertFalse("socket should not be closed", socket.isClosed());
+            assertTrue(socket.isConnected(), "socket is not connected");
+            assertFalse(socket.isClosed(), "socket should not be closed");
             socket.close();
-            assertTrue("socket has not closed", socket.isClosed());
+            assertTrue(socket.isClosed(), "socket has not closed");
         }
     }
 
